With a functional and tested backend for virtio-block live migration,
add the virtio-block device ID to the pci_device_id table.

Currently, the driver supports legacy IO functionality only for
virtio-net, and it is accounted for in specific parts of the code.

To enforce this limitation, an explicit check for virtio-net, has been
added in virtiovf_support_legacy_io(). Once a backend implements legacy
IO functionality for virtio-block, the necessary support will be added
to the driver, and this additional check should be removed.

The module description was updated accordingly.

Reviewed-by: Kevin Tian <kevin.t...@intel.com>
Signed-off-by: Yishai Hadas <yish...@nvidia.com>
---
Changes from V0:
https://lore.kernel.org/kvm/20250227155444.57354e74.alex.william...@redhat.com/T/

- Replace "NET,BLOCK" with "NET and BLOCK" for readability, as was
  suggested by Alex.
- Make the tristate summary more generic as was suggeted by Kevin and
  Alex.
- Add Kevin Tian Reviewed-by clause.

 drivers/vfio/pci/virtio/Kconfig     | 6 +++---
 drivers/vfio/pci/virtio/legacy_io.c | 4 +++-
 drivers/vfio/pci/virtio/main.c      | 5 +++--
 3 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/drivers/vfio/pci/virtio/Kconfig b/drivers/vfio/pci/virtio/Kconfig
index 2770f7eb702c..33e04e65bec6 100644
--- a/drivers/vfio/pci/virtio/Kconfig
+++ b/drivers/vfio/pci/virtio/Kconfig
@@ -1,11 +1,11 @@
 # SPDX-License-Identifier: GPL-2.0-only
 config VIRTIO_VFIO_PCI
-       tristate "VFIO support for VIRTIO NET PCI VF devices"
+       tristate "VFIO support for VIRTIO PCI VF devices"
        depends on VIRTIO_PCI
        select VFIO_PCI_CORE
        help
-         This provides migration support for VIRTIO NET PCI VF devices
-         using the VFIO framework. Migration support requires the
+         This provides migration support for VIRTIO NET and BLOCK PCI VF
+         devices using the VFIO framework. Migration support requires the
          SR-IOV PF device to support specific VIRTIO extensions,
          otherwise this driver provides no additional functionality
          beyond vfio-pci.
diff --git a/drivers/vfio/pci/virtio/legacy_io.c 
b/drivers/vfio/pci/virtio/legacy_io.c
index 20382ee15fac..832af5ba267c 100644
--- a/drivers/vfio/pci/virtio/legacy_io.c
+++ b/drivers/vfio/pci/virtio/legacy_io.c
@@ -382,7 +382,9 @@ static bool virtiovf_bar0_exists(struct pci_dev *pdev)
 
 bool virtiovf_support_legacy_io(struct pci_dev *pdev)
 {
-       return virtio_pci_admin_has_legacy_io(pdev) && 
!virtiovf_bar0_exists(pdev);
+       /* For now, the legacy IO functionality is supported only for 
virtio-net */
+       return pdev->device == 0x1041 && virtio_pci_admin_has_legacy_io(pdev) &&
+              !virtiovf_bar0_exists(pdev);
 }
 
 int virtiovf_init_legacy_io(struct virtiovf_pci_core_device *virtvdev)
diff --git a/drivers/vfio/pci/virtio/main.c b/drivers/vfio/pci/virtio/main.c
index d534d48c4163..515fe1b9f94d 100644
--- a/drivers/vfio/pci/virtio/main.c
+++ b/drivers/vfio/pci/virtio/main.c
@@ -187,8 +187,9 @@ static void virtiovf_pci_remove(struct pci_dev *pdev)
 }
 
 static const struct pci_device_id virtiovf_pci_table[] = {
        /* Only virtio-net is supported/tested so far */
        { PCI_DRIVER_OVERRIDE_DEVICE_VFIO(PCI_VENDOR_ID_REDHAT_QUMRANET, 
0x1041) },
+       { PCI_DRIVER_OVERRIDE_DEVICE_VFIO(PCI_VENDOR_ID_REDHAT_QUMRANET, 
0x1042) },
        {}
 };
 
@@ -221,4 +222,4 @@ module_pci_driver(virtiovf_pci_driver);
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Yishai Hadas <yish...@nvidia.com>");
 MODULE_DESCRIPTION(
-       "VIRTIO VFIO PCI - User Level meta-driver for VIRTIO NET devices");
+       "VIRTIO VFIO PCI - User Level meta-driver for VIRTIO NET and BLOCK 
@@ -187,8 +187,9 @@ static void virtiovf_pci_remove(struct pci_dev *pdev)
 
 static const struct pci_device_id virtiovf_pci_table[] = {
-       /* Only virtio-net is supported/tested so far */
+       /* Only virtio-net and virtio-block are supported/tested so far */
        { PCI_DRIVER_OVERRIDE_DEVICE_VFIO(PCI_VENDOR_ID_REDHAT_QUMRANET, 
0x1041) },
devices");
-- 
2.18.1


Reply via email to